@@ -4,7 +4,7 @@ Main interface for finspace-data service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_finspace_data import (
         Client,
         FinSpaceDataClient,
@@ -13,10 +13,8 @@ Usage::
         ListDatasetsPaginator,
     )
 
-    session = boto3.Session()
-
-    client: FinSpaceDataClient = boto3.client("finspace-data")
-    session_client: FinSpaceDataClient = session.client("finspace-data")
+    session = Session()
+    client: FinSpaceDataClient = session.client("finspace-data")
 
     list_changesets_paginator: ListChangesetsPaginator = client.get_paginator("list_changesets")
     list_data_views_paginator: ListDataViewsPaginator = client.get_paginator("list_data_views")
