@@ -21,6 +21,7 @@ from .literals import (
     DatasetStatusType,
     DataViewStatusType,
     ErrorCategoryType,
+    ExportFileFormatType,
     IngestionStatusType,
     locationTypeType,
 )
@@ -99,6 +100,7 @@ ChangesetSummaryTypeDef = TypedDict(
         "status": IngestionStatusType,
         "errorInfo": "ChangesetErrorInfoTypeDef",
         "activeUntilTimestamp": int,
+        "activeFromTimestamp": int,
         "updatesChangesetId": str,
         "updatedByChangesetId": str,
     },
@@ -188,16 +190,16 @@ _RequiredCreateDatasetRequestRequestTypeDef = TypedDict(
     {
         "datasetTitle": str,
         "kind": DatasetKindType,
-        "datasetDescription": str,
         "permissionGroupParams": "PermissionGroupParamsTypeDef",
-        "alias": str,
     },
 )
 _OptionalCreateDatasetRequestRequestTypeDef = TypedDict(
     "_OptionalCreateDatasetRequestRequestTypeDef",
     {
         "clientToken": str,
+        "datasetDescription": str,
         "ownerInfo": "DatasetOwnerInfoTypeDef",
+        "alias": str,
         "schemaDefinition": "SchemaUnionTypeDef",
     },
     total=False,
@@ -228,12 +230,27 @@ CredentialsTypeDef = TypedDict(
     total=False,
 )
 
-DataViewDestinationTypeParamsTypeDef = TypedDict(
-    "DataViewDestinationTypeParamsTypeDef",
+_RequiredDataViewDestinationTypeParamsTypeDef = TypedDict(
+    "_RequiredDataViewDestinationTypeParamsTypeDef",
     {
         "destinationType": str,
     },
 )
+_OptionalDataViewDestinationTypeParamsTypeDef = TypedDict(
+    "_OptionalDataViewDestinationTypeParamsTypeDef",
+    {
+        "s3DestinationExportFileFormat": ExportFileFormatType,
+        "s3DestinationExportFileFormatOptions": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class DataViewDestinationTypeParamsTypeDef(
+    _RequiredDataViewDestinationTypeParamsTypeDef, _OptionalDataViewDestinationTypeParamsTypeDef
+):
+    pass
+
 
 DataViewErrorInfoTypeDef = TypedDict(
     "DataViewErrorInfoTypeDef",
@@ -340,6 +357,7 @@ GetChangesetResponseTypeDef = TypedDict(
         "status": IngestionStatusType,
         "errorInfo": "ChangesetErrorInfoTypeDef",
         "activeUntilTimestamp": int,
+        "activeFromTimestamp": int,
         "updatesChangesetId": str,
         "updatedByChangesetId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -620,7 +638,6 @@ _RequiredUpdateDatasetRequestRequestTypeDef = TypedDict(
         "datasetId": str,
         "datasetTitle": str,
         "kind": DatasetKindType,
-        "alias": str,
     },
 )
 _OptionalUpdateDatasetRequestRequestTypeDef = TypedDict(
@@ -628,6 +645,7 @@ _OptionalUpdateDatasetRequestRequestTypeDef = TypedDict(
     {
         "clientToken": str,
         "datasetDescription": str,
+        "alias": str,
         "schemaDefinition": "SchemaUnionTypeDef",
     },
     total=False,
